==> visual-third-party-0.4.9-lg-sources.jar: com/tenqube/visual_third/web/SystemImpl.java <==
package com.tenqube.visual_third.web;

import android.app.FragmentManager;
import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Handler;
import android.webkit.JavascriptInterface;
import android.webkit.WebView;

import com.tenqube.visual_third.exception.ParameterException;
import com.tenqube.visual_third.ui.NotiCatchDialogFragment;
import com.tenqube.visual_third.ui.NotiIntroActivity;
import com.tenqube.visual_third.ui.VisualWebActivity;
import com.tenqube.visual_third.util.Utils;

import static com.tenqube.visual_third.ui.VisualWebActivity.NOTIFICATION_REQUEST_CODE;
import static com.tenqube.visual_third.util.Validator.isStr;

public class SystemImpl extends Base implements VisualInterface.System  {

    private String callbackNoti;

    public SystemImpl(VisualWebActivity activity, WebView webView, VisualInterface.Error error) {
        super(activity, webView, error);
    }

    public void onNotiCallback(final String json) {
        callbackWithStr(callbackNoti, json);
    }

    @JavascriptInterface
    public void startNotiListener(final String callback) {

        String funcName = "startNotiListener";
//        NotiRequest notiRequest = null;
        try {
//            notiRequest = fromJson(params, NotiRequest.class);
//            notiRequest.checkParams();
            // params 파싱해서 callback 구하기
            this.callbackNoti = callback;

            if(isNotiEnabled()) {
                goNotiSettings(callbackNoti);
            } else {
                NotiCatchDialogFragment notiCatchDialogFragment = NotiCatchDialogFragment.newInstance("");

                notiCatchDialogFragment.setCallback(new NotiCatchDialogFragment.Callback() {
                    @Override
                    public void onClickNext() {
                        goNotiSettings(callbackNoti);
                    }
                });

                if(!notiCatchDialogFragment.isAdded()) {
                    FragmentManager fragmentManager = activity.getFragmentManager();
                    if(fragmentManager != null) {
                        fragmentManager.beginTransaction().add(notiCatchDialogFragment, NotiCatchDialogFragment.TAG).commitAllowingStateLoss();
                    }
                }
            }


        } catch (Exception e) {

            onError(funcName, e.toString());
        }
    }

    @JavascriptInterface
    public void goNotiSettings(final String callback) {

        String funcName = "goNotiSettings";
        try {

            isStr(callback, 100);
            // params 파싱해서 callback 구하기
            this.callbackNoti = callback;

            try {
                Intent i = new Intent("android.settings.ACTION_NOTIFICATION_LISTENER_SETTINGS");
                i.putExtra(":settings:fragment_args_key",  "com.lge.lgpay/com.tenqube.visual_third.parser.catcher.NotiCatcher");
                activity.startActivityForResult(i, NOTIFICATION_REQUEST_CODE);

//                new Handler().postDelayed(new Runnable() {
//                    @Override
//                    public void run() {
//                        Intent intent = new Intent(activity, NotiIntroActivity.class);
//                        activity.startActivity(intent);
//                    }
//                }, 500);


            } catch (ActivityNotFoundException e){

                onError(funcName, e.toString());
            }

        } catch (ParameterException e) {
            onError(funcName, e.toString());
        } catch (Exception e) {

            onError(funcName, e.toString());
        }
    }

    @JavascriptInterface
    public boolean isNotiEnabled() {

        String funcName = "isNotiEnabled";
        try {
            return Utils.isNotiEnabled(activity.getApplicationContext());
        } catch (Exception e) {

            onError(funcName, e.toString());
        }
        return false;
    }

    /**
     * 네트워크 연결 여부
     */
    @JavascriptInterface
    public boolean isNetworkConnected() {

        String funcName = "isNetworkConnected";

        try {
            ConnectivityManager cm =
                    (ConnectivityManager)activity.getSystemService(Context.CONNECTIVITY_SERVICE);

            NetworkInfo activeNetwork = cm.getActiveNetworkInfo();
            boolean isConnected = activeNetwork != null &&
                    activeNetwork.isConnectedOrConnecting();

            return isConnected;
        } catch (Exception e) {

            onError(funcName, e.toString());
        }
        return true;

    }

}

==> visual-third-party-0.6.1-lg-sources.jar: com/tenqube/visual_third/web/SystemImpl.java <==
package com.tenqube.visual_third.web;

import android.app.FragmentManager;
import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Handler;
import android.webkit.JavascriptInterface;
import android.webkit.WebView;

import com.tenqube.visual_third.ActivityCallback;
import com.tenqube.visual_third.exception.ParameterException;
import com.tenqube.visual_third.ui.NotiCatchDialogFragment;
import com.tenqube.visual_third.ui.NotiIntroActivity;
import com.tenqube.visual_third.ui.VisualWebActivity;
import com.tenqube.visual_third.util.Utils;

import static com.tenqube.visual_third.ui.VisualWebActivity.NOTIFICATION_REQUEST_CODE;
import static com.tenqube.visual_third.util.Validator.isStr;

public class SystemImpl extends Base implements VisualInterface.System  {

    private String callbackNoti;

    public SystemImpl(ActivityCallback activity, WebView webView, VisualInterface.Error error) {
        super(activity, webView, error);
    }

    public void onNotiCallback(final String json) {
        callbackWithStr(callbackNoti, json);
    }

    @JavascriptInterface
    public void startNotiListener(final String callback) {

        String funcName = "startNotiListener";
//        NotiRequest notiRequest = null;
        try {
//            notiRequest = fromJson(params, NotiRequest.class);
//            notiRequest.checkParams();
            // params 파싱해서 callback 구하기
            this.callbackNoti = callback;

            if(isNotiEnabled()) {
                goNotiSettings(callbackNoti);
            } else {
                NotiCatchDialogFragment notiCatchDialogFragment = NotiCatchDialogFragment.newInstance("");

                notiCatchDialogFragment.setCallback(new NotiCatchDialogFragment.Callback() {
                    @Override
                    public void onClickNext() {
                        goNotiSettings(callbackNoti);
                    }
                });

                if(!notiCatchDialogFragment.isAdded()) {
                    FragmentManager fragmentManager = activity.getActivity().getFragmentManager();
                    if(fragmentManager != null) {
                        fragmentManager.beginTransaction().add(notiCatchDialogFragment, NotiCatchDialogFragment.TAG).commitAllowingStateLoss();
                    }
                }
            }


        } catch (Exception e) {

            onError(funcName, e.toString());
        }
    }

    @JavascriptInterface
    public void goNotiSettings(final String callback) {

        String funcName = "goNotiSettings";
        try {

            isStr(callback, 100);
            // params 파싱해서 callback 구하기
            this.callbackNoti = callback;

            try {
                Intent i = new Intent("android.settings.ACTION_NOTIFICATION_LISTENER_SETTINGS");
                i.putExtra(":settings:fragment_args_key",  "com.lge.lgpay/com.tenqube.visual_third.parser.catcher.NotiCatcher");
                activity.getActivity().startActivityForResult(i, NOTIFICATION_REQUEST_CODE);

//                new Handler().postDelayed(new Runnable() {
//                    @Override
//                    public void run() {
//                        Intent intent = new Intent(activity, NotiIntroActivity.class);
//                        activity.startActivity(intent);
//                    }
//                }, 500);


            } catch (ActivityNotFoundException e){

                onError(funcName, e.toString());
            }

        } catch (ParameterException e) {
            onError(funcName, e.toString());
        } catch (Exception e) {

            onError(funcName, e.toString());
        }
    }

    @JavascriptInterface
    public boolean isNotiEnabled() {

        String funcName = "isNotiEnabled";
        try {
            return Utils.isNotiEnabled(activity.getContext());
        } catch (Exception e) {

            onError(funcName, e.toString());
        }
        return false;
    }

    /**
     * 네트워크 연결 여부
     */
    @JavascriptInterface
    public boolean isNetworkConnected() {

        String funcName = "isNetworkConnected";

        try {
            ConnectivityManager cm =
                    (ConnectivityManager)activity.getActivity().getSystemService(Context.CONNECTIVITY_SERVICE);

            NetworkInfo activeNetwork = cm.getActiveNetworkInfo();
            boolean isConnected = activeNetwork != null &&
                    activeNetwork.isConnectedOrConnecting();

            return isConnected;
        } catch (Exception e) {

            onError(funcName, e.toString());
        }
        return true;

    }

}
